]> sigrok.org Git - libsigrok.git/commitdiff
strutil: Now using base 10 in sr_atol(), sr_atoi() for compatibility to atoi(), atol...
authorMatthias Heidbrink <redacted>
Mon, 19 May 2014 17:40:53 +0000 (19:40 +0200)
committerMatthias Heidbrink <redacted>
Mon, 19 May 2014 17:40:53 +0000 (19:40 +0200)
strutil.c

index e63f12e18e9dfb8a4e8b6dd371c03c4453a6a4f2..47975d2048165992b0d9fbc532617212bd9cb871 100644 (file)
--- a/strutil.c
+++ b/strutil.c
@@ -46,7 +46,7 @@
 /**
  * @private
  *
* Convert a string representation of a numeric value to a long integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid long integer. The function sets errno according to the details of the
  * failure.
@@ -54,7 +54,8 @@
  * @param str The string representation to convert.
  * @param ret Pointer to long where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -64,7 +65,7 @@ SR_PRIV int sr_atol(const char *str, long *ret)
        char *endptr = NULL;
 
        errno = 0;
-       tmp = strtol(str, &endptr, 0);
+       tmp = strtol(str, &endptr, 10);
 
        if (!endptr || *endptr || errno) {
                if (!errno)
@@ -79,7 +80,7 @@ SR_PRIV int sr_atol(const char *str, long *ret)
 /**
  * @private
  *
* Convert a string representation of a numeric value to an integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid integer. The function sets errno according to the details of the
  * failure.
@@ -87,7 +88,8 @@ SR_PRIV int sr_atol(const char *str, long *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to int where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -118,7 +120,8 @@ SR_PRIV int sr_atoi(const char *str, int *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to double where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -151,7 +154,8 @@ SR_PRIV int sr_atod(const char *str, double *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to float where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -182,7 +186,8 @@ SR_PRIV int sr_atof(const char *str, float *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to float where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -46,7 +46,7 @@
  * @private
  *
- * Convert a string representation of a numeric value to a long integer. The
+ * Convert a string representation of a numeric value (base 10) to a long integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid long integer. The function sets errno according to the details of the
@@ -79,7 +80,7 @@ SR_PRIV int sr_atol(const char *str, long *ret)
  * @private
  *
- * Convert a string representation of a numeric value to an integer. The
+ * Convert a string representation of a numeric value (base 10) to an integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid integer. The function sets errno according to the details of the